<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>FractalGeneratorApp</name>
    <message>
        <location filename="fractalgenerator.cc" line="100"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="102"/>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="103"/>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="104"/>
        <source>&amp;Save</source>
        <translation>&amp;Lagre</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="105"/>
        <source>Save As ...</source>
        <oldsource>Save As</oldsource>
        <translation>Lagre som ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="107"/>
        <source>&amp;Export ...</source>
        <oldsource>&amp;Export Image</oldsource>
        <translation>&amp;Eksporter ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="108"/>
        <source>&amp;Print ...</source>
        <oldsource>Print &amp;Image</oldsource>
        <translation>Skriv ut ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="110"/>
        <source>&amp;Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="111"/>
        <source>&amp;Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="114"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="116"/>
        <source>&amp;Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="117"/>
        <source>Copy Selection</source>
        <translation>Kopier utvalg</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="120"/>
        <source>Zoom &amp;In</source>
        <translation>Zoom inn</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="122"/>
        <source>Zoom &amp;Back</source>
        <translation>Zoom tilbake</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="125"/>
        <source>&amp;Reset Zoom</source>
        <translation>Tilbakestill zoom</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="128"/>
        <source>&amp;Format</source>
        <translation>&amp;Format</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="131"/>
        <source>Custom Image Size</source>
        <translation>Egendefinert bildestørrelse</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="134"/>
        <source>Swap Width and Height</source>
        <translation>Bytt bredde og høyde</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="200"/>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="441"/>
        <location filename="fractalgenerator.cc" line="454"/>
        <source>Image Size</source>
        <translation>Bildestørrelse</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="155"/>
        <source>&amp;Algorithm</source>
        <translation>Algoritme</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="157"/>
        <source>Configure Algorithm ...</source>
        <oldsource>Configure Algorithm</oldsource>
        <translation>Konfigurer algoritme ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="177"/>
        <source>&amp;Color Scheme</source>
        <translation>&amp;Fargevalg</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="197"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="199"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="205"/>
        <source>Fractal.pdf</source>
        <translation>Fraktal.pdf</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="207"/>
        <source>Welcome to FractGen!</source>
        <oldsource>Welcome to Fractal Generator!</oldsource>
        <translation>Velkommen til FractGen!</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="237"/>
        <source>Opening file ...</source>
        <oldsource>Opening file...</oldsource>
        <translation>Åpner fil ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="239"/>
        <source>Open File ...</source>
        <translation>Åpne fil ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="241"/>
        <location filename="fractalgenerator.cc" line="275"/>
        <source>FractGen File (*.fsf)</source>
        <translation>FractGen-fil (*.fsf)</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="454"/>
        <source>Invalid image size!</source>
        <translation>Ugyldig bildestørrelse!</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="245"/>
        <location filename="fractalgenerator.cc" line="264"/>
        <location filename="fractalgenerator.cc" line="279"/>
        <location filename="fractalgenerator.cc" line="298"/>
        <location filename="fractalgenerator.cc" line="319"/>
        <location filename="fractalgenerator.cc" line="364"/>
        <location filename="fractalgenerator.cc" line="416"/>
        <location filename="fractalgenerator.cc" line="462"/>
        <source>Ready</source>
        <oldsource>Ready.</oldsource>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="271"/>
        <source>Saving file as ...</source>
        <translation>Lagre fil som ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="273"/>
        <source>Save File ...</source>
        <translation>Lagre fil ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="252"/>
        <source>Saving file...</source>
        <translation>Lagrer fil ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="256"/>
        <source>Overwrite existing file?</source>
        <oldsource>Overwrite existing file </oldsource>
        <translation>Erstatt eksisterende fil?</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="286"/>
        <source>Exporting Image ...</source>
        <translation>Eksporterer bilde ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="288"/>
        <source>Export Image</source>
        <translation>Eksport bilde</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="312"/>
        <source>Printing...</source>
        <translation>Skriver ut ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="431"/>
        <source>Changing Image Size ...</source>
        <translation>Endre bildestørrelse ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="442"/>
        <source>Please enter new size in the format x*y:</source>
        <translation>Vennligst skriv inn ny bildestørrelse i formatet x*y:</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="360"/>
        <source>Changing Options ...</source>
        <translation>Endre innstillinger ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="413"/>
        <source>Click middle mouse button or choose &quot;View -&gt; Zoom In&quot; to magnify selected area!</source>
        <translation>Klikk midtre museknapp eller velg &quot;Vis -&gt; Zoom inn&quot; for å forstørre det valgte området!</translation>
    </message>
</context>
<context>
    <name>FractalGeneratorDoc</name>
    <message>
        <location filename="fractalgeneratordoc.cc" line="62"/>
        <source>Unnamed.fsf</source>
        <translation>Uten navn.fsf</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="94"/>
        <location filename="fractalgeneratordoc.cc" line="104"/>
        <location filename="fractalgeneratordoc.cc" line="121"/>
        <location filename="fractalgeneratordoc.cc" line="135"/>
        <source>Open File Failure</source>
        <translation>Feil ved åpning av fil</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="96"/>
        <location filename="fractalgeneratordoc.cc" line="106"/>
        <source>Line: </source>
        <translation>Rad:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="97"/>
        <location filename="fractalgeneratordoc.cc" line="107"/>
        <source>Column: </source>
        <translation>Kolonne:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="122"/>
        <source>Invalid AlgorithmName entry:</source>
        <translation>Ugyldig AlgorithmName-oppføring:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="136"/>
        <source>Invalid ColorSchemeName entry:</source>
        <translation>Ugyldig ColorSchemeName-oppføring:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="174"/>
        <source>Open File Warning</source>
        <translation>Advarsel ved åpning av fil</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="175"/>
        <source>Skipping unknown entry:</source>
        <translation>Hopp over ukjent oppføring:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="277"/>
        <source>Save File Failure</source>
        <translation>Feil ved skriving av fil</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.cc" line="34"/>
        <source>Fractal Algorithm Options</source>
        <translation>Innstillinger for fraktalalgoritme</translation>
    </message>
    <message>
        <location filename="optionsdialog.cc" line="42"/>
        <source>Parameter Name</source>
        <translation>Parameternavn</translation>
    </message>
    <message>
        <location filename="optionsdialog.cc" line="46"/>
        <source>Parameter Value</source>
        <translation>Parameterverd</translation>
    </message>
    <message>
        <location filename="optionsdialog.cc" line="72"/>
        <source>&amp;Okay</source>
        <translation>&amp;Okay</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="clifractgen.cc" line="46"/>
        <source>FSF input file.</source>
        <oldsource>FSF input file</oldsource>
        <translation>FSF-inndatafil.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="48"/>
        <source>Graphics output file.</source>
        <oldsource>Graphics output file</oldsource>
        <translation>Grafikkutdatafil.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="53"/>
        <source>Width.</source>
        <oldsource>Width</oldsource>
        <translation>Bredde.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="61"/>
        <source>Height.</source>
        <oldsource>Height</oldsource>
        <translation>Høyde.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="69"/>
        <source>Maximum number of iterations.</source>
        <oldsource>Maximum number of iterations</oldsource>
        <translation>Maksimalt antall iterasjoner.</translation>
    </message>
</context>
</TS>
